=============================================================
pySOT: Surrogate Optimization Toolbox
=============================================================

pySOT is an optimization toolbox for global deterministic optimization problems.
The main purpose of the toolbox is for optimization of computationally expensive
black-box objective functions with continuous and/or integer variables where the
number of evaluations is limited.

The toolbox is hosted on GitHub: https://github.com/dme65/pySOT

Please refer to pySOT.pdf for more details about the functionality of the toolbox.

Check out the new GUI